Django REST Dataclasses
=======================

|Build Status| |PyPI version| |Coveralls Status|

**Django REST Framework integration with Dataclasses**

Provides serializers for dataclasses

.. |Build Status| image:: https://travis-ci.org/shosca/django-rest-dataclasses.svg?branch=master
   :target: https://travis-ci.org/shosca/django-rest-dataclasses
.. |PyPI version| image:: https://badge.fury.io/py/django-rest-dataclasses.svg
   :target: https://badge.fury.io/py/django-rest-dataclasses
.. |Coveralls Status| image:: https://coveralls.io/repos/github/shosca/django-rest-dataclasses/badge.svg?branch=master
   :target: https://coveralls.io/github/shosca/django-rest-dataclasses?branch=master
